
import java.util.Collection;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.FlushModeType;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceUnit;
import javax.persistence.Query;

@Stateless
public class EmployeeService implements EmployeeServiceLocal, EmployeeServiceRemote {
  @PersistenceContext(unitName="EmployeeService")
  EntityManager em;
  
  @PersistenceUnit(unitName="EmployeeService") private EntityManagerFactory factory;

  public EmployeeService() {
  }

  public Employee createEmployee(int id, String name, long salary, byte[] pic) {
    Employee emp = new Employee(id);
    emp.setName(name);
    emp.setSalary(salary);
    
    em.persist(emp);
    
    emp = findEmployee(id);
    System.out.println(emp);
    
    return emp;
  }

  public void removeEmployee(int id) {
    Employee emp = findEmployee(id);
    if (emp != null) {
      em.remove(emp);
    }
  }

  public Employee raiseEmployeeSalary(int id, long raise) {
    Employee emp = em.find(Employee.class, id);
    if (emp != null) {
      emp.setSalary(emp.getSalary() + raise);
    }
    return emp;
  }

  public Employee findEmployee(int id) {
    return em.find(Employee.class, id);
  }

  public Collection<Employee> findAllEmployees() {
    Query query = em.createQuery("SELECT e FROM Employee e");
    return (Collection<Employee>) query.getResultList();
  }
  
  public void doAction(){
    
    EntityManager createdManager = factory.createEntityManager();
    createdManager.setFlushMode(FlushModeType.COMMIT);
    
    Employee emp = new Employee(2);
    emp.setName("name");
    emp.setSalary(200);
        
    createdManager.persist(emp);
    //createdManager.flush();

    
    emp = em.find(Employee.class, 2);
    
    System.out.println(emp);
  }

}

    